// Copyright (c) 2016, 2018, 2022, Oracle and/or its affiliates.  All rights reserved.
// This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
// Code generated. DO NOT EDIT.

package vulnerabilityscanning

import (
	"github.com/oracle/oci-go-sdk/v56/common"
	"net/http"
)

// ListContainerScanRecipesRequest wrapper for the ListContainerScanRecipes operation
//
// See also
//
// Click https://docs.cloud.oracle.com/en-us/iaas/tools/go-sdk-examples/latest/vulnerabilityscanning/ListContainerScanRecipes.go.html to see an example of how to use ListContainerScanRecipesRequest.
type ListContainerScanRecipesRequest struct {

	// The ID of the compartment in which to list resources.
	CompartmentId *string `mandatory:"true" contributesTo:"query" name:"compartmentId"`

	// A filter to return only resources whose lifecycleState matches the given lifecycleState.
	LifecycleState ListContainerScanRecipesLifecycleStateEnum `mandatory:"false" contributesTo:"query" name:"lifecycleState" omitEmpty:"true"`

	// A filter to return only resources that match the entire display name given.
	DisplayName *string `mandatory:"false" contributesTo:"query" name:"displayName"`

	// The maximum number of items to return.
	Limit *int `mandatory:"false" contributesTo:"query" name:"limit"`

	// The page token representing the page at which to start retrieving results. This is usually retrieved from a previous list call.
	Page *string `mandatory:"false" contributesTo:"query" name:"page"`

	// The sort order to use, either 'ASC' or 'DESC'.
	SortOrder ListContainerScanRecipesSortOrderEnum `mandatory:"false" contributesTo:"query" name:"sortOrder" omitEmpty:"true"`

	// The field to sort by. Only one sort order may be provided. Default order for timeCreated is descending. Default order for displayName is ascending. If no value is specified timeCreated is default.
	SortBy ListContainerScanRecipesSortByEnum `mandatory:"false" contributesTo:"query" name:"sortBy" omitEmpty:"true"`

	// The client request ID for tracing.
	OpcRequestId *string `mandatory:"false" contributesTo:"header" name:"opc-request-id"`

	// Metadata about the request. This information will not be transmitted to the service, but
	// represents information that the SDK will consume to drive retry behavior.
	RequestMetadata common.RequestMetadata
}

func (request ListContainerScanRecipesRequest) String() string {
	return common.PointerString(request)
}

// HTTPRequest implements the OCIRequest interface
func (request ListContainerScanRecipesRequest) HTTPRequest(method, path string, binaryRequestBody *common.OCIReadSeekCloser, extraHeaders map[string]string) (http.Request, error) {

	return common.MakeDefaultHTTPRequestWithTaggedStructAndExtraHeaders(method, path, request, extraHeaders)
}

// BinaryRequestBody implements the OCIRequest interface
func (request ListContainerScanRecipesRequest) BinaryRequestBody() (*common.OCIReadSeekCloser, bool) {

	return nil, false

}

// RetryPolicy implements the OCIRetryableRequest interface. This retrieves the specified retry policy.
func (request ListContainerScanRecipesRequest) RetryPolicy() *common.RetryPolicy {
	return request.RequestMetadata.RetryPolicy
}

// ListContainerScanRecipesResponse wrapper for the ListContainerScanRecipes operation
type ListContainerScanRecipesResponse struct {

	// The underlying http response
	RawResponse *http.Response

	// A list of ContainerScanRecipeSummaryCollection instances
	ContainerScanRecipeSummaryCollection `presentIn:"body"`

	// Unique Oracle-assigned identifier for the request. If you need to contact
	// Oracle about a particular request, please provide the request ID.
	OpcRequestId *string `presentIn:"header" name:"opc-request-id"`

	// For pagination of a list of items. When paging through a list, if this header appears in the response,
	// then a partial list might have been returned. Include this value as the `page` parameter for the
	// subsequent GET request to get the next batch of items.
	OpcNextPage *string `presentIn:"header" name:"opc-next-page"`
}

func (response ListContainerScanRecipesResponse) String() string {
	return common.PointerString(response)
}

// HTTPResponse implements the OCIResponse interface
func (response ListContainerScanRecipesResponse) HTTPResponse() *http.Response {
	return response.RawResponse
}

// ListContainerScanRecipesLifecycleStateEnum Enum with underlying type: string
type ListContainerScanRecipesLifecycleStateEnum string

// Set of constants representing the allowable values for ListContainerScanRecipesLifecycleStateEnum
const (
	ListContainerScanRecipesLifecycleStateCreating ListContainerScanRecipesLifecycleStateEnum = "CREATING"
	ListContainerScanRecipesLifecycleStateUpdating ListContainerScanRecipesLifecycleStateEnum = "UPDATING"
	ListContainerScanRecipesLifecycleStateActive   ListContainerScanRecipesLifecycleStateEnum = "ACTIVE"
	ListContainerScanRecipesLifecycleStateDeleting ListContainerScanRecipesLifecycleStateEnum = "DELETING"
	ListContainerScanRecipesLifecycleStateDeleted  ListContainerScanRecipesLifecycleStateEnum = "DELETED"
	ListContainerScanRecipesLifecycleStateFailed   ListContainerScanRecipesLifecycleStateEnum = "FAILED"
)

var mappingListContainerScanRecipesLifecycleState = map[string]ListContainerScanRecipesLifecycleStateEnum{
	"CREATING": ListContainerScanRecipesLifecycleStateCreating,
	"UPDATING": ListContainerScanRecipesLifecycleStateUpdating,
	"ACTIVE":   ListContainerScanRecipesLifecycleStateActive,
	"DELETING": ListContainerScanRecipesLifecycleStateDeleting,
	"DELETED":  ListContainerScanRecipesLifecycleStateDeleted,
	"FAILED":   ListContainerScanRecipesLifecycleStateFailed,
}

// GetListContainerScanRecipesLifecycleStateEnumValues Enumerates the set of values for ListContainerScanRecipesLifecycleStateEnum
func GetListContainerScanRecipesLifecycleStateEnumValues() []ListContainerScanRecipesLifecycleStateEnum {
	values := make([]ListContainerScanRecipesLifecycleStateEnum, 0)
	for _, v := range mappingListContainerScanRecipesLifecycleState {
		values = append(values, v)
	}
	return values
}

// ListContainerScanRecipesSortOrderEnum Enum with underlying type: string
type ListContainerScanRecipesSortOrderEnum string

// Set of constants representing the allowable values for ListContainerScanRecipesSortOrderEnum
const (
	ListContainerScanRecipesSortOrderAsc  ListContainerScanRecipesSortOrderEnum = "ASC"
	ListContainerScanRecipesSortOrderDesc ListContainerScanRecipesSortOrderEnum = "DESC"
)

var mappingListContainerScanRecipesSortOrder = map[string]ListContainerScanRecipesSortOrderEnum{
	"ASC":  ListContainerScanRecipesSortOrderAsc,
	"DESC": ListContainerScanRecipesSortOrderDesc,
}

// GetListContainerScanRecipesSortOrderEnumValues Enumerates the set of values for ListContainerScanRecipesSortOrderEnum
func GetListContainerScanRecipesSortOrderEnumValues() []ListContainerScanRecipesSortOrderEnum {
	values := make([]ListContainerScanRecipesSortOrderEnum, 0)
	for _, v := range mappingListContainerScanRecipesSortOrder {
		values = append(values, v)
	}
	return values
}

// ListContainerScanRecipesSortByEnum Enum with underlying type: string
type ListContainerScanRecipesSortByEnum string

// Set of constants representing the allowable values for ListContainerScanRecipesSortByEnum
const (
	ListContainerScanRecipesSortByTimecreated ListContainerScanRecipesSortByEnum = "timeCreated"
	ListContainerScanRecipesSortByDisplayname ListContainerScanRecipesSortByEnum = "displayName"
)

var mappingListContainerScanRecipesSortBy = map[string]ListContainerScanRecipesSortByEnum{
	"timeCreated": ListContainerScanRecipesSortByTimecreated,
	"displayName": ListContainerScanRecipesSortByDisplayname,
}

// GetListContainerScanRecipesSortByEnumValues Enumerates the set of values for ListContainerScanRecipesSortByEnum
func GetListContainerScanRecipesSortByEnumValues() []ListContainerScanRecipesSortByEnum {
	values := make([]ListContainerScanRecipesSortByEnum, 0)
	for _, v := range mappingListContainerScanRecipesSortBy {
		values = append(values, v)
	}
	return values
}
